catalog

package
v0.0.0-...-2bd5d0f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 4, 2026 License: AGPL-3.0 Imports: 11 Imported by: 0

Documentation

Overview

Package catalog loads the application content embedded in the server binary.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Content

type Content struct {
	Seed               store.SeedContent
	SystemRules        []api.Rule
	BanksJSON          []byte
	ReaderGuides       map[string][]byte
	PromptCatalog      *llm.PromptCatalog
	OpenAIModelOptions []llm.ModelOption
}

Content is the validated, typed application content loaded at startup.

func Load

func Load() (Content, error)

Load parses and validates all bundled application content.

Jump to